aboutsummaryrefslogtreecommitdiff
path: root/platform
diff options
context:
space:
mode:
Diffstat (limited to 'platform')
-rw-r--r--platform/desktop/GLFW/glfw3.h (renamed from platform/gl/GLFW/glfw3.h)0
-rw-r--r--platform/desktop/GLFW/glfw3native.h (renamed from platform/gl/GLFW/glfw3native.h)0
-rw-r--r--platform/desktop/desktop.c (renamed from platform/gl/gl.c)6
-rw-r--r--platform/desktop/glad/KHR/khrplatform.h (renamed from platform/gl/glad/KHR/khrplatform.h)0
-rw-r--r--platform/desktop/glad/glad.c (renamed from platform/gl/glad/glad.c)0
-rw-r--r--platform/desktop/glad/glad.h (renamed from platform/gl/glad/glad.h)0
6 files changed, 3 insertions, 3 deletions
diff --git a/platform/gl/GLFW/glfw3.h b/platform/desktop/GLFW/glfw3.h
index 9c55ac9..9c55ac9 100644
--- a/platform/gl/GLFW/glfw3.h
+++ b/platform/desktop/GLFW/glfw3.h
diff --git a/platform/gl/GLFW/glfw3native.h b/platform/desktop/GLFW/glfw3native.h
index 92f0d32..92f0d32 100644
--- a/platform/gl/GLFW/glfw3native.h
+++ b/platform/desktop/GLFW/glfw3native.h
diff --git a/platform/gl/glad/KHR/khrplatform.h b/platform/desktop/glad/KHR/khrplatform.h
index 0164644..0164644 100644
--- a/platform/gl/glad/KHR/khrplatform.h
+++ b/platform/desktop/glad/KHR/khrplatform.h
diff --git a/platform/gl/glad/glad.c b/platform/desktop/glad/glad.c
index 27295bf..27295bf 100644
--- a/platform/gl/glad/glad.c
+++ b/platform/desktop/glad/glad.c
diff --git a/platform/gl/glad/glad.h b/platform/desktop/glad/glad.h
index e30aabd..e30aabd 100644
--- a/platform/gl/glad/glad.h
+++ b/platform/desktop/glad/glad.h
diff --git a/platform/gl/gl.c b/platform/desktop/desktop.c
index 3f15160..9574c9c 100644
--- a/platform/gl/gl.c
+++ b/platform/desktop/desktop.c
@@ -1,4 +1,4 @@
// The OpenGL platform. Uses GLFW for an interface with the OS. The code
// quality here is meh. Things could be organized more into functions, but as
// for now, it works fine, and isn't worth improving immediately.
@@ -45,9 +45,9 @@ typedef struct {
GLint uniform_tex_loc;
GLuint screen_handle;
uint32_t typed;
-} Gl_Platform;
+} Desktop_Platform;
-Gl_Platform p;
+Desktop_Platform p;
static
void character_callback(GLFWwindow *window, unsigned int cp)
@@ -1,4 +1,4 @@
-// The OpenGL platform. Uses GLFW for an interface with the OS. The code
+// The desktop platform. Uses GLFW for an interface with the OS. The code
// quality here is meh. Things could be organized more into functions, but as
// for now, it works fine, and isn't worth improving immediately.